from django.shortcuts import render
from django.http import HttpResponse, HttpResponseBadRequest, HttpResponseNotAllowed, HttpResponseNotFound
from django.shortcuts import redirect
from django.contrib.auth.decorators import login_required
from warpauth.ldap_connector import LDAPConnector
from warpauth.models import LdapUser
from warpauth.util import *


##
# http://www.python-ldap.org/doc/html/ldap.html#ldap.LDAPObject
##

@login_required(login_url='/login/', redirect_field_name=None)
def index(request):
    pages["error"] = ""
    pages["success"] = False
    pages['ldap_groups'] = request.user.ldap_user.group_names
    return HttpResponse(render(request, 'warpauth/profile.html', pages))


@login_required(login_url='/login/', redirect_field_name=None)
def change_password(request):
    pages["error"] = ""
    pages["success"] = False

    if request.method != 'POST':
        redirect("/")

    if "old_pw" not in request.POST or "new_pw" not in request.POST or "new_pw_confirm" not in request.POST:
        pages["error"] = "Please fill in all fields"
    elif request.POST["new_pw"] != request.POST["new_pw_confirm"]:
        pages["error"] = "Password confirmation did not match"
    else:
        ldap_connector = LDAPConnector()
        ret = ldap_connector.change_password(request.user.ldap_user.dn, request.POST["old_pw"], request.POST["new_pw"])
        if ret == -1:
            pages["error"] = "Old password did not match"
        else:
            pages["success"] = True
    return HttpResponse(render(request, 'warpauth/profile.html', pages))
